@@ -992,6 +992,29 @@ class CynosdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeZones(self, request):
+        """本接口(DescribeZones)用于查询可售卖地域可用区信息。
+
+        :param request: Request instance for DescribeZones.
+        :type request: :class:`tencentcloud.cynosdb.v20190107.models.DescribeZonesRequest`
+        :rtype: :class:`tencentcloud.cynosdb.v20190107.models.DescribeZonesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeZones", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeZonesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisassociateSecurityGroups(self, request):
         """安全组批量解绑云资源
 
@@ -1429,6 +1452,29 @@ class CynosdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyVipVport(self, request):
+        """修改实例组ip，端口
+
+        :param request: Request instance for ModifyVipVport.
+        :type request: :class:`tencentcloud.cynosdb.v20190107.models.ModifyVipVportRequest`
+        :rtype: :class:`tencentcloud.cynosdb.v20190107.models.ModifyVipVportResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyVipVport", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyVipVportResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def OfflineCluster(self, request):
         """下线集群
 
@@ -1728,6 +1774,29 @@ class CynosdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SwitchClusterVpc(self, request):
+        """更换集群vpc
+
+        :param request: Request instance for SwitchClusterVpc.
+        :type request: :class:`tencentcloud.cynosdb.v20190107.models.SwitchClusterVpcRequest`
+        :rtype: :class:`tencentcloud.cynosdb.v20190107.models.SwitchClusterVpcResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SwitchClusterVpc", params, headers=headers)
+            response = json.loads(body)
+            model = models.SwitchClusterVpcResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SwitchClusterZone(self, request):
         """切换到从可用区
 
